@@ -33,8 +33,9 @@ setClass(Class = "MxExpectationRAM",
 	    .rampartUnitLimit = "integer",
 	    .useSufficientSets = "logical",
 	    .forceSingleGroup = "logical",
-	    .ignoreDefVarsHack = "logical", #remove TODO
-	    .identifyZeroVarPred = "logical"
+	    .identifyZeroVarPred = "logical",
+	    .maxDebugGroups = "integer",
+	    .optimizeMean = "integer"
 	),
 	contains = "BaseExpectationNormal")
 
@@ -57,9 +58,10 @@ setMethod("initialize", "MxExpectationRAM",
 		.Object@.rampartCycleLimit <- as.integer(NA)
 		.Object@.rampartUnitLimit <- as.integer(NA)
 		.Object@.forceSingleGroup <- FALSE
-		.Object@.ignoreDefVarsHack <- FALSE  # remove TODO
 		.Object@.identifyZeroVarPred <- TRUE
 		.Object@.useSufficientSets <- TRUE
+		.Object@.maxDebugGroups <- 0L
+		.Object@.optimizeMean <- 2L
 		return(.Object)
 	}
 )
