@@ -239,24 +239,6 @@ runHelper <- function(model, frontendStart,
 		names(parameters), names(constraints), model@compute, output)
 	
 	theFitUnits <- model$output$fitUnits
-	if(length(theFitUnits) > 0 && theFitUnits %in% "r'Wr" ){
-		if(options[["Standard Errors"]] == "Yes"){
-			wlsSEs <- imxWlsStandardErrors(model)
-			model@output$standardErrors <- wlsSEs$SE
-			model@output$ihessian <- 0.5*wlsSEs$Cov
-			model@output$hessian <- 2*solve(wlsSEs$Cov) #puts in same units as m2ll Hessian
-			wlsChi <- imxWlsChiSquare(model, J=wlsSEs$Jac)
-		} else {
-			wlsChi <- list(Chi=NA, ChiDoF=NA)
-		}
-		model@output$chi <- wlsChi$Chi
-		model@output$chiDoF <- wlsChi$ChiDoF
-		model@output$chiM <- wlsChi$ChiM
-		model@output$chiMV <- wlsChi$ChiMV
-		model@output$chiMadjust <- wlsChi$mAdjust
-		model@output$chiMVadjust <- wlsChi$mvAdjust
-		model@output$chiDoFstar <- wlsChi$dstar
-	}
 	if (is.na(model@output$status$code) ||
 	    (!is.na(model@output$status$code) && model@output$status$code < 5)) {
 		if (!is.null(model@output[['infoDefinite']]) &&
