@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 The OpenMx Project
+#   Copyright 2007-2018 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -122,23 +122,23 @@ oneFactorFit<-mxRun(oneFactorModel)
 summary(oneFactorFit)
 coef(oneFactorFit)
 
-omxCheckCloseEnough(oneFactorFit$output$estimate[["l2"]], 0.999, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["l3"]], 0.959, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["l4"]], 1.028, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["l5"]], 1.008, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["l6"]], 1.021, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["varF1"]], 0.645, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["e1"]], 0.350, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["e2"]], 0.379, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["e3"]], 0.389, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["e4"]], 0.320, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["e5"]], 0.370, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["e6"]], 0.346, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx1"]], 2.988, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx2"]], 3.011, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx3"]], 2.986, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx4"]], 3.053, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx5"]], 3.016, 0.01)
-omxCheckCloseEnough(oneFactorFit$output$estimate[["meanx6"]], 3.010, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["l2"]], 0.999, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["l3"]], 0.959, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["l4"]], 1.028, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["l5"]], 1.008, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["l6"]], 1.021, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["varF1"]], 0.645, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["e1"]], 0.350, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["e2"]], 0.379, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["e3"]], 0.389, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["e4"]], 0.320, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["e5"]], 0.370, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["e6"]], 0.346, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["meanx1"]], 2.988, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["meanx2"]], 3.011, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["meanx3"]], 2.986, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["meanx4"]], 3.053, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["meanx5"]], 3.016, 0.01)
+omxCheckCloseEnough(coef(oneFactorFit)[["meanx6"]], 3.010, 0.01)
 # Compare OpenMx results to Mx results 
 # -----------------------------------------------------------------------------
