@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2018 The OpenMx Project
+#   Copyright 2007-2018 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -73,10 +73,10 @@ uniRegFit$output
 # Print the outputs populated by mxRun
 # -----------------------------------------------------------------------------
 
-omxCheckCloseEnough(uniRegFit$output$estimate[["beta0"]], 2.5478, 0.001)
-omxCheckCloseEnough(uniRegFit$output$estimate[["beta1"]], 0.4831, 0.001)
-omxCheckCloseEnough(uniRegFit$output$estimate[["residual"]], 0.6652, 0.001)
-omxCheckCloseEnough(uniRegFit$output$estimate[["meanx"]], 0.0542, 0.001)
-omxCheckCloseEnough(uniRegFit$output$estimate[["varx"]], 1.1053, 0.001)
+omxCheckCloseEnough(coef(uniRegFit)[["beta0"]], 2.5478, 0.001)
+omxCheckCloseEnough(coef(uniRegFit)[["beta1"]], 0.4831, 0.001)
+omxCheckCloseEnough(coef(uniRegFit)[["residual"]], 0.6652, 0.001)
+omxCheckCloseEnough(coef(uniRegFit)[["meanx"]], 0.0542, 0.001)
+omxCheckCloseEnough(coef(uniRegFit)[["varx"]], 1.1053, 0.001)
 # Compare OpenMx results to Mx results 
-# -----------------------------------------------------------------------------
\ No newline at end of file
+# -----------------------------------------------------------------------------
