@@ -84,6 +84,6 @@ h2se <- sqrt(
 			(sum(scm)*(pointest[1]+pointest[2])^-2)
 ))
 #Compare:
-mxEval(h2,testrun,T) + 2*c(-h2se,h2se)
+mxEval(h2,testrun,T)[1,1] + 2*c(-h2se,h2se)
 testrun$output$confidenceIntervals
 
