@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2018 The OpenMx Project
+ *  Copyright 2007-2018 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -271,10 +271,7 @@ void omxComputeNM::computeImpl(FitContext *fc){
 	
 	NelderMeadOptimizerContext nmoc(fc, this);
 
-	if (nmoc.numFree <= 0) {
-		omxRaiseErrorf("%s: model has no free parameters", name);
-		return;
-	}
+	if (nmoc.numFree <= 0) { complainNoFreeParam(); return; }
 	
 	nmoc.verbose = verbose;
 	nmoc.maxIter = maxIter;
@@ -295,7 +292,7 @@ void omxComputeNM::computeImpl(FitContext *fc){
 			if(verbose){mxLog("l1p iteration %d",k);}
 			if(k>0){
 				if(nmoc.iniSimplexMat.rows() || nmoc.iniSimplexMat.cols()){nmoc.iniSimplexMat.resize(0,0);}
-				if(nmoc.statuscode==10){break;}
+				if(nmoc.statuscode==10 || Global->timedOut){break;}
 				if( !nmoc.estInfeas && nmoc.statuscode==0 ){
 					if(verbose){mxLog("l1p solution found");}
 					break;
@@ -303,6 +300,11 @@ void omxComputeNM::computeImpl(FitContext *fc){
 				if(nmoc.estInfeas){
 					nmoc.rho *= 10;
 					if(verbose){mxLog("penalty factor rho = %f",nmoc.rho);}
+					nmoc.iniSimplexEdge = iniSimplexEdge;
+				}
+				else{ //It's making progress w/r/t the constraints, so re-initialize the simplex with a smaller edge:
+					nmoc.iniSimplexEdge = 
+						sqrt((nmoc.vertices[1] - nmoc.vertices[0]).dot(nmoc.vertices[1] - nmoc.vertices[0]));
 				}
 				if(fc->iterations >= maxIter){
 					nmoc.statuscode = 4;
@@ -335,6 +337,9 @@ void omxComputeNM::computeImpl(FitContext *fc){
 		nmoc2.addPenalty = nmoc.addPenalty;
 		nmoc2.countConstraintsAndSetupBounds();
 		nmoc2.invokeNelderMead();
+		if(nmoc2.statuscode==10){
+			fc->resetIterationError();
+		}
 		
 		if(nmoc2.bestfit < nmoc.bestfit && (nmoc2.statuscode==0 || nmoc2.statuscode==4)){
 			nmoc.bestfit = nmoc2.bestfit;
@@ -349,6 +354,9 @@ void omxComputeNM::computeImpl(FitContext *fc){
 				nmoc.equality = nmoc2.equality;
 				nmoc.inequality = nmoc2.inequality;
 			}
+			else if(Global->timedOut){ //i.e., if time ran out during the validation restart
+				nmoc.statuscode = 4;
+			}
 		}
 		
 		//Not sure about this:
@@ -359,7 +367,7 @@ void omxComputeNM::computeImpl(FitContext *fc){
 		nmoc.calculatePseudoHessian();
 	}
 	
-	if(nmoc.estInfeas){nmoc.statuscode = 3;}
+	if(nmoc.estInfeas && nmoc.statuscode!=10){nmoc.statuscode = 3;}
 	
 	switch(nmoc.statuscode){
 	case -1:
@@ -1295,7 +1303,7 @@ bool NelderMeadOptimizerContext::checkConvergence(){
 			return(true);
 		}
 	}
-	if(itersElapsed >= maxIter){
+	if(itersElapsed >= maxIter || isErrorRaised() || Global->timedOut){
 		statuscode = 4;
 		return(true);
 	}
@@ -1344,7 +1352,7 @@ void NelderMeadOptimizerContext::invokeNelderMead(){
 	eucentroidCurr.resize(numFree);
 	initializeSimplex(est, iniSimplexEdge, false);
 	if( (vertexInfeas.sum()==n+1 && NMobj->eqConstraintMthd != 4) || (fvals.array()==bignum).all()){
-		omxRaiseErrorf("initial simplex is not feasible; specify it differently, try different start values, or use mxTryHard()");
+		fc->recordIterationError("initial simplex is not feasible; specify it differently, try different start values, or use mxTryHard()");
 		statuscode = 10;
 		return;
 	}
@@ -1579,7 +1587,7 @@ void NelderMeadOptimizerContext::finalize()
 	/*Doing this here ensures (1) that the fit has just been freshly evaluated at the solution, (2) that this check is done as part of the
 	MxComputeNelderMead step (necessary for bootstrapping), and (3) that Nelder-Mead reports status code 3 for solutions that violate 
 	MxConstraints, and status code 10 for	all other kinds of infeasible solutions:*/
-	if(!fc->insideFeasibleSet()){fc->setInform(INFORM_STARTING_VALUES_INFEASIBLE);}
+	if(!fc->insideFeasibleSet() && (statuscode==0 || statuscode==4)){fc->setInform(INFORM_STARTING_VALUES_INFEASIBLE);}
 	
 	omxState *st = fc->state;
 	int ineqType = omxConstraint::LESS_THAN;
