@@ -192,7 +192,7 @@ SEXP mtmvnorm(SEXP Rsigma, SEXP Rlower, SEXP Rupper)
 	delete fc;
 	delete globalState;
 
-	omxManageProtectInsanity mpi;
+	ProtectAutoBalanceDoodad mpi;
 	MxRList result;
 	result.add("tmean", Rcpp::wrap(tmean));
 	result.add("tvar", Rcpp::wrap(tcov));
@@ -426,7 +426,7 @@ static void readOpts(SEXP options, int *numThreads, int *analyticGradients)
 /* Main functions */
 SEXP omxCallAlgebra2(SEXP matList, SEXP algNum, SEXP options) {
 
-	omxManageProtectInsanity protectManager;
+	ProtectAutoBalanceDoodad protectManager;
 
 	if(OMX_DEBUG) { mxLog("-----------------------------------------------------------------------");}
 	if(OMX_DEBUG) { mxLog("Explicit call to algebra %d.", INTEGER(algNum)[0]);}
@@ -509,14 +509,12 @@ SEXP omxBackend2(SEXP constraints, SEXP matList,
 		 SEXP data, SEXP intervalList, SEXP checkpointList, SEXP options,
 		 SEXP defvars, bool silent)
 {
-	SEXP nextLoc;
-
 	/* Sanity Check and Parse Inputs */
 	/* TODO: Need to find a way to account for nullness in these.  For now, all checking is done on the front-end. */
 //	if(!isVector(matList)) Rf_error ("matList must be a list");
 //	if(!isVector(algList)) Rf_error ("algList must be a list");
 
-	omxManageProtectInsanity protectManager;
+	ProtectAutoBalanceDoodad protectManager;
 
 	FitContext::setRFitFunction(NULL);
 	Global = new omxGlobal;
@@ -558,7 +556,7 @@ SEXP omxBackend2(SEXP constraints, SEXP matList,
 	*/
 	if (Global->debugProtectStack) mxLog("Protect depth at line %d: %d", __LINE__, protectManager.getDepth());
 	for(int j = 0; j < Rf_length(matList); j++) {
-		Rf_protect(nextLoc = VECTOR_ELT(matList, j));		// This is the matrix + populations
+		ProtectedSEXP nextLoc(VECTOR_ELT(matList, j));		// This is the matrix + populations
 		globalState->matrixList[j]->omxProcessMatrixPopulationList(nextLoc);
 	}
 
@@ -781,7 +779,6 @@ static R_CallMethodDef callMethods[] = {
 	{".dtmvnorm.marginal2", (DL_FUNC) dtmvnorm_marginal2, 7},
 	{".mtmvnorm", (DL_FUNC) mtmvnorm, 3},
 	{".enableMxLog", (DL_FUNC) &enableMxLog, 0},
-	{".storeData", (DL_FUNC) storeData, 2},
 	{NULL, NULL, 0}
 };
 
